@@ -117,7 +117,7 @@ impl Show for Cluster {
     fn detailed_show(&self) -> String {
         let helm = k8s::Helm::new(true);
         let namespace = self.namespace.as_deref().unwrap_or("statehub-system");
-        let helm = helm.command(self, namespace);
+        let helm = helm.command(self, None, namespace);
         format!(
             "{}\n{}\n{}\n{}\n{}\n{}",
             format_args!("Cluster:     {}", self.name),
