@@ -186,9 +186,9 @@ impl State {
 impl StateLocationStatus {
     const OK: Emoji<'static, 'static> = Emoji("🆗", "[v]");
     // const PROVISIONING: Emoji<'static, 'static> = Emoji("⤴ 🔜", "[+]");
-    const PROVISIONING: Emoji<'static, 'static> = Emoji("⤴", "[+]");
+    const PROVISIONING: Emoji<'static, 'static> = Emoji("⤴\u{fe0f}", "[+]");
     const RECOVERING: Emoji<'static, 'static> = Emoji("🔄", "[~]");
-    const DELETING: Emoji<'static, 'static> = Emoji("⤵", "[-]");
+    const DELETING: Emoji<'static, 'static> = Emoji("⤵\u{fe0f}", "[-]");
     const ERROR: Emoji<'static, 'static> = Emoji("❌", "[x]");
 
     pub fn as_str(&self) -> &'static str {
